@@ -21,9 +21,10 @@ our @EXPORT = qw(
 use Devel::NYTProf::Data;
 use Devel::NYTProf::Reader;
 use Devel::NYTProf::Util qw(strip_prefix_from_paths html_safe_filename);
-use Devel::NYTProf::Run qw(perl_command_words);
 
-my $diff_opts = ($Config{osname} eq 'MSWin32') ? '-c' : '-u';
+
+my $this_perl = $^X;
+$this_perl .= $Config{_exe} if $^O ne 'VMS' and $this_perl !~ m/$Config{_exe}$/i;
 
 my %opts = (
     one          => $ENV{NYTPROF_TEST_ONE},
@@ -68,12 +69,7 @@ chdir('t') if -d 't';
 if (-d '../blib') {
     unshift @INC, '../blib/arch', '../blib/lib';
 }
-my $bindir      = (grep {-d} qw(./blib/script ../blib/script))[0] || do {
-    my $bin = (grep {-d} qw(./bin ../bin))[0]
-        or die "Can't find scripts";
-    warn "Couldn't find blib/script directory, so using $bin";
-    $bin;
-};
+my $bindir      = (grep {-d} qw(./blib/script ../blib/script))[0];
 my $nytprofcsv  = "$bindir/nytprofcsv";
 my $nytprofhtml = "$bindir/nytprofhtml";
 my $nytprofmerge= "$bindir/nytprofmerge";
@@ -286,9 +282,7 @@ sub run_test {
             or die "Profiling $test failed\n";
 
         if ($opts{html}) {
-            my $htmloutdir = "/tmp/$outdir";
-            unlink <$htmloutdir/*>;
-            my $cmd = "$perl $nytprofhtml --file=$profile_datafile --out=$htmloutdir";
+            my $cmd = "$perl $nytprofhtml --file=$profile_datafile --out=$outdir";
             $cmd .= " --open" if $opts{open};
             run_command($cmd);
         }
@@ -347,12 +341,9 @@ sub run_command {
 }
 
 
-# some tests use profile_this() in Devel::NYTProf::Run
 sub run_perl_command {
     my ($cmd, $show_stdout) = @_;
-    local $ENV{PERL5LIB} = $perl5lib;
-    my @perl = perl_command_words(skip_sitecustomize => 1);
-    run_command("@perl $cmd", $show_stdout);
+    run_command("$this_perl $cmd", $show_stdout);
 }
 
 
@@ -377,7 +368,7 @@ sub verify_data {
     SKIP: {
         skip 'Expected profile data does not have VMS paths', 1
             if $^O eq 'VMS' and $test =~ m/test60|test14/i;
-        $profile->normalize_variables;
+	$profile->normalize_variables;
         dump_profile_to_file($profile, $test.'_new', $test.'_newp');
         my @got      = slurp_file($test.'_new'); chomp @got;
         my @expected = slurp_file($test);        chomp @expected;
@@ -416,11 +407,13 @@ sub dump_profile_to_file {
     return;
 }
 
+
 sub diff_files {
     my ($old_file, $new_file, $newp_file) = @_;
 
     # we don't care if this fails, it's just an aid to debug test failures
-    my @opts = split / /, $ENV{NYTPROF_DIFF_OPTS} || $diff_opts;    # e.g. '-y'
+    my @opts = split / /, $ENV{NYTPROF_DIFF_OPTS} || '';    # e.g. '-y'
+    @opts = ('-u') unless @opts;
     system("cmp -s $new_file $newp_file || diff @opts $old_file $new_file 1>&2");
 }
 
@@ -441,7 +434,7 @@ sub verify_csv_report {
     $csvfile =~ s/\.x//;
     $csvfile .= ".p" unless $csvfile =~ /\.p/;
     $csvfile = html_safe_filename($csvfile);
-    $csvfile = "$outdir/${csvfile}-1-line.csv";
+    $csvfile = "$outdir/${csvfile}-line.csv";
     unlink $csvfile;
 
     my $cmd = "$perl $nytprofcsv --file=$profile_datafile --out=$outdir";
@@ -593,4 +586,4 @@ sub count_of_failed_tests {
 
 1;
 
-# vim:ts=8:sw=4:et
+# vim:ts=8:sw=4
